<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Document</title>
  </head>
  <body>
    <main>
      <{{ title_tag }}>Hello World!</{{ title_tag }}>
      <p>This is an example HTML page for test.</p>
    </main>
  </body>
</html>
